==> Mudlib-CD.00.28.tar.gz: lib/std/leftover.c <==
/*
 * leftover.c 
 *
 * Base leftover code.
 *
 * This code basically works just like /std/food.c . The main difference
 * really is the set_decay_time() call which determines how long the object
 * can remain in a room before it decays, like a corpse. If the object is
 * put inside any container, not based on a room (like a player) it will
 * not decay. It will resume decaying as soon as it is put back in any room.
 * The decay time is measured in minutes.
 */

#pragma save_binary
#include <stdproperties.h>
#include <composite.h>
#include <macros.h>
#include <cmdparse.h>
#include <language.h>

int decay_time;		/* The time it takes for the food to decay in min */
int simple_names;	/* Setup of simple names or not */
string l_organ, l_race; /* Race and organ name */

inherit "/std/food";
public void decay_fun();

public void
create_leftover()
{
    simple_names = 1;
    set_amount(10);
}

public void
leftover_init(string organ, string race)
{
    l_organ = organ;
    l_race = race;

    if (simple_names)
    {
	set_name(({ organ, race + " " + organ }));
	set_long("This is the torn and bloody remains of " +
		 LANG_ADDART(race + " " + organ) + ".\n");
    }
}

public nomask void
create_food() 
{ 
    simple_names = 0;
    decay_time = 10;
    create_leftover();
}

public void
set_decay_time(int time)
{
    decay_time = time;
}

public int
query_decay_time()
{
    return decay_time;
}

public string
query_race()
{
    return l_race;
}

public string
query_organ()
{
    return l_organ;
}

public void 
enter_env(object dest, object old) 
{
    if (function_exists("create_container", dest) != "/std/room")
	remove_call_out("decay_fun");
    else
	decay_fun();
}

public void
decay_fun()
{
    if (--decay_time)
	call_out("decay_fun", 60);
    else
    {
	tell_room(environment(this_object()), "The " + QSHORT(this_object()) +
	    " rapidly decays.\n");
	remove_object();
    }
}

/*
 * Function name:	consume_them 
 * Description:		Consumes a number of food item. This function
 *			shadows the ordinary /std/food funcion.
 *			All this to detect cannibals...
 * Arguments:		arr: Array of food objects.
 */
public void
consume_them(object *arr)
{
    int il;
    
    for (il = 0; il < sizeof(arr); il++)
    {
        if (arr[il]->query_race() == this_player()->query_race_name())
	{
	    write("You feel a bit uneasy doing this, but...\n");
	    this_player()->add_prop("cannibal", 1);
	}
	arr[il]->delay_destruct();
    }
}

==> Mudlib-CD.00.30.tar.gz: lib/std/leftover.c <==
/*
 * leftover.c 
 *
 * Base leftover code.
 *
 * This code basically works just like /std/food.c . The main difference
 * really is the set_decay_time() call which determines how long the object
 * can remain in a room before it decays, like a corpse. If the object is
 * put inside any container, not based on a room (like a player) it will
 * not decay. It will resume decaying as soon as it is put back in any room.
 * The decay time is measured in minutes.
 */

#pragma save_binary

inherit "/std/food";

#include <stdproperties.h>
#include <composite.h>
#include <macros.h>
#include <cmdparse.h>
#include <language.h>

int decay_time;		/* The time it takes for the food to decay in min */
int simple_names;	/* Setup of simple names or not */
string l_organ, l_race; /* Race and organ name */

public void decay_fun();

public void
create_leftover()
{
    simple_names = 1;
    set_amount(10);
}

public void
leftover_init(string organ, string race)
{
    l_organ = organ;
    l_race = race;

    if (simple_names)
    {
	set_name(({ organ, race + " " + organ }));
	set_long("This is the torn and bloody remains of " +
		 LANG_ADDART(race + " " + organ) + ".\n");
    }
}

public nomask void
create_food() 
{ 
    simple_names = 0;
    decay_time = 10;
    create_leftover();
}

public void
set_decay_time(int time)
{
    decay_time = time;
}

public int
query_decay_time()
{
    return decay_time;
}

public string
query_race()
{
    return l_race;
}

public string
query_organ()
{
    return l_organ;
}

public void 
enter_env(object dest, object old) 
{
    if (function_exists("create_container", dest) != "/std/room")
	remove_call_out("decay_fun");
    else
	decay_fun();
}

public void
decay_fun()
{
    if (--decay_time)
	call_out("decay_fun", 60);
    else
    {
	tell_room(environment(this_object()), capitalize(LANG_THESHORT(this_object())) +
	    " rapidly decays.\n");
	remove_object();
    }
}

/*
 * Function name:	consume_them 
 * Description:		Consumes a number of food item. This function
 *			shadows the ordinary /std/food funcion.
 *			All this to detect cannibals...
 * Arguments:		arr: Array of food objects.
 */
public void
consume_them(object *arr)
{
    int il;
    
    for (il = 0; il < sizeof(arr); il++)
    {
        if (arr[il]->query_race() == this_player()->query_race_name())
	{
	    write("You feel a bit uneasy doing this, but...\n");
	    this_player()->add_prop("cannibal", 1);
	}
	arr[il]->delay_destruct();
    }
}
